@@ -101,9 +101,11 @@ class TestKuryrBase(TestCase):
 
     @staticmethod
     def _get_fake_v6_subnetpools(subnetpool_id, prefixes=['fe80::/64'],
-                                 name="kuryr6"):
+                                 name="kuryr6", tags=None):
         # The following fake response is retrieved from the Neutron doc:
         #   http://developer.openstack.org/api-ref-networking-v2-ext.html#listSubnetPools  # noqa
+        if tags is None:
+            tags = []
         v6_subnetpools = {
             "subnetpools": [{
                 "min_prefixlen": "64",
@@ -116,7 +118,8 @@ class TestKuryrBase(TestCase):
                 "tenant_id": "9fadcee8aa7c40cdb2114fff7d569c08",
                 "prefixes": prefixes,
                 "ip_version": 6,
-                "shared": False
+                "shared": False,
+                "tags": tags,
             }]
         }
 
@@ -169,7 +172,9 @@ class TestKuryrBase(TestCase):
                        neutron_trunk_id=None,
                        tags=None,
                        name=None,
-                       binding_profile=None):
+                       binding_profile=None,
+                       binding_host=None,
+                       admin_state_up=True):
         # The following fake response is retrieved from the Neutron doc:
         #   http://developer.openstack.org/api-ref-networking-v2.html#createPort  # noqa
         if not name:
@@ -179,7 +184,7 @@ class TestKuryrBase(TestCase):
                 "status": neutron_port_status,
                 "name": name,
                 "allowed_address_pairs": [],
-                "admin_state_up": True,
+                "admin_state_up": admin_state_up,
                 "network_id": neutron_network_id,
                 "tenant_id": "d6700c0c9ffa4f1cb322cd4a1f3906fa",
                 "device_owner": device_owner,
@@ -195,6 +200,9 @@ class TestKuryrBase(TestCase):
         if binding_profile is not None:
             fake_port['port']['binding:profile'] = binding_profile
 
+        if binding_host is not None:
+            fake_port['port']['binding:host_id'] = binding_host
+
         if neutron_subnet_v4_id:
             fake_port['port']['fixed_ips'].append({
                 "subnet_id": neutron_subnet_v4_id,
@@ -215,12 +223,14 @@ class TestKuryrBase(TestCase):
                         fake_neutron_port_id, neutron_port_status,
                         fake_neutron_subnet_v4_id, fake_neutron_subnet_v6_id,
                         neutron_subnet_v4_address="192.168.1.2",
-                        neutron_subnet_v6_address="fe80::f816:3eff:fe20:57c4"):
+                        neutron_subnet_v6_address="fe80::f816:3eff:fe20:57c4",
+                        tags=None):
         fake_port = cls._get_fake_port(
             docker_endpoint_id, neutron_network_id,
             fake_neutron_port_id, neutron_port_status,
             fake_neutron_subnet_v4_id, fake_neutron_subnet_v6_id,
-            neutron_subnet_v4_address, neutron_subnet_v6_address)
+            neutron_subnet_v4_address, neutron_subnet_v6_address,
+            tags=tags)
         fake_port = fake_port['port']
         fake_ports = {
             'ports': [
@@ -233,7 +243,7 @@ class TestKuryrBase(TestCase):
     @staticmethod
     def _get_fake_v4_subnet(neutron_network_id, docker_endpoint_id=None,
                             subnet_v4_id=None, subnetpool_id=None,
-                            cidr='192.168.1.0/24',
+                            cidr='192.168.1.0/24', tag_subnetpool_id=True,
                             name=None, host_routes=None, tags=None):
         if host_routes is None:
             host_routes = []
@@ -266,16 +276,19 @@ class TestKuryrBase(TestCase):
         }
         if subnetpool_id:
             fake_v4_subnet['subnet'].update(subnetpool_id=subnetpool_id)
-            fake_v4_subnet['subnet'].get('tags').append(subnetpool_id)
+            if tag_subnetpool_id:
+                fake_v4_subnet['subnet'].get('tags').append(subnetpool_id)
 
         return fake_v4_subnet
 
     @staticmethod
     def _get_fake_v6_subnet(docker_network_id, docker_endpoint_id=None,
                             subnet_v6_id=None, subnetpool_id=None,
-                            cidr='fe80::/64', name=None):
+                            cidr='fe80::/64', name=None, tags=None):
         if not name:
             name = str('-'.join([docker_endpoint_id, 'fe80::']))
+        if not tags:
+            tags = []
         gateway_ip = netaddr.IPNetwork(cidr).network + 1
         start_ip = gateway_ip + 1
         end_ip = netaddr.IPNetwork(cidr).broadcast - 1
@@ -292,7 +305,8 @@ class TestKuryrBase(TestCase):
                 "ip_version": 6,
                 "cidr": cidr,
                 "id": subnet_v6_id,
-                "enable_dhcp": True
+                "enable_dhcp": True,
+                "tags": tags,
             }
         }
         if subnetpool_id:
